==> rendition-9.4.0.tgz: package/dist_esm5/components/Modal.js <==
import * as tslib_1 from "tslib";
import { Layer } from 'grommet';
import assign from 'lodash/assign';
import * as React from 'react';
import styled, { createGlobalStyle, withTheme } from 'styled-components';
import { stopPropagation } from '../utils';
import { px } from '../utils';
import Button from './Button';
import { Box, Flex } from './Grid';
import Txt from './Txt';
var bodyNoOverflowClass = "rendition-modal-open";
var GlobalStyle = createGlobalStyle(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"], ["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"])), bodyNoOverflowClass);
var DEFAULT_MODAL_WIDTH = 700;
var ModalHeader = styled(Txt)(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\tmargin-bottom: 50px;\n\tfont-size: ", ";\n"], ["\n\tmargin-bottom: 50px;\n\tfont-size: ", ";\n"])), function (props) { return px(props.theme.fontSizes[4]); });
var ModalTitleDetails = styled(Txt)(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tcolor: ", ";\n\tfont-size: ", ";\n"], ["\n\tcolor: ", ";\n\tfont-size: ", ";\n"])), function (props) { return props.theme.colors.text.light; }, function (props) { return px(props.theme.fontSizes[2]); });
var ModalSizer = styled(Box)(templateObject_4 || (templateObject_4 = tslib_1.__makeTemplateObject(["\n\tmax-width: 100%;\n\toverflow-y: auto;\n"], ["\n\tmax-width: 100%;\n\toverflow-y: auto;\n"])));
var ModalButton = function (props) {
    return 'href' in props && props.href ? (React.createElement(Button, tslib_1.__assign({ as: "a" }, props))) : (React.createElement(Button, tslib_1.__assign({}, props)));
};
var Modal = (function (_super) {
    tslib_1.__extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.ownIndex = 0;
        _this.handleKeyDown = function (e) {
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            if (!e.defaultPrevented && (e.which === 13 || e.which === 27)) {
                e.preventDefault();
                e.stopPropagation();
                if (e.which === 13) {
                    _this.props.done();
                }
                if (e.which === 27) {
                    (_this.props.cancel || _this.props.done)();
                }
            }
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (!Modal.mountedCount) {
            document.body.classList.add(bodyNoOverflowClass);
        }
        window.document.addEventListener('keydown', this.handleKeyDown);
        Modal.mountedCount++;
        this.ownIndex = Modal.mountedCount;
    };
    Modal.prototype.componentWillUnmount = function () {
        Modal.mountedCount--;
        if (!Modal.mountedCount) {
            document.body.classList.remove(bodyNoOverflowClass);
        }
        window.document.removeEventListener('keydown', this.handleKeyDown);
    };
    Modal.prototype.render = function () {
        var _a = this.props, width = _a.width, theme = _a.theme, props = tslib_1.__rest(_a, ["width", "theme"]);
        var cancelButtonProps = assign({ style: { marginRight: 20 } }, props.cancelButtonProps);
        var secondaryButtonProps = assign({
            primary: true,
            outline: true,
            style: { marginRight: 20 },
        }, props.secondaryButtonProps);
        var primaryButtonProps = assign({ primary: true }, props.primaryButtonProps);
        return (React.createElement(Layer, { onEsc: function () { return (props.cancel || props.done)(); }, onClickOutside: function () { return (props.cancel || props.done)(); }, responsive: false, margin: "small", animate: false },
            React.createElement(GlobalStyle, null),
            React.createElement(ModalSizer, { p: [px(theme.space[3]), '40px 50px 30px'], width: width || DEFAULT_MODAL_WIDTH, onClick: stopPropagation, style: props.style, id: props.id, className: props.className },
                props.titleElement ? (React.createElement(ModalHeader, null, props.titleElement)) : (!!props.title && (React.createElement(ModalHeader, null,
                    React.createElement("strong", null, props.title),
                    !!props.titleDetails && (React.createElement(ModalTitleDetails, null, props.titleDetails))))),
                props.children,
                React.createElement(Flex, { mt: 50, alignItems: "center", justifyContent: "flex-end" },
                    props.cancel && (React.createElement(ModalButton, tslib_1.__assign({}, cancelButtonProps, { onClick: props.cancel }), (cancelButtonProps && cancelButtonProps.children) || 'Cancel')),
                    props.secondaryButtonProps && (React.createElement(ModalButton, tslib_1.__assign({}, secondaryButtonProps))),
                    React.createElement(ModalButton, tslib_1.__assign({}, primaryButtonProps, { onClick: props.done }), props.action || 'OK')))));
    };
    Modal.mountedCount = 0;
    return Modal;
}(React.Component));
export default withTheme(Modal);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

==> rendition-9.10.0.tgz: package/dist_esm5/components/Modal.js <==
import * as tslib_1 from "tslib";
import { Layer } from 'grommet';
import assign from 'lodash/assign';
import * as React from 'react';
import styled, { createGlobalStyle, withTheme } from 'styled-components';
import { stopPropagation } from '../utils';
import { px } from '../utils';
import Button from './Button';
import { Box, Flex } from './Grid';
import Heading from './Heading';
import Txt from './Txt';
var bodyNoOverflowClass = "rendition-modal-open";
var GlobalStyle = createGlobalStyle(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"], ["\n\t.", " {\n\t\toverflow: hidden;\n\t}\n"])), bodyNoOverflowClass);
var DEFAULT_MODAL_WIDTH = 700;
var ModalSizer = styled(Box)(templateObject_2 || (templateObject_2 = tslib_1.__makeTemplateObject(["\n\tmax-width: 100%;\n\toverflow-y: auto;\n"], ["\n\tmax-width: 100%;\n\toverflow-y: auto;\n"])));
var HeadingDescription = styled(Txt)(templateObject_3 || (templateObject_3 = tslib_1.__makeTemplateObject(["\n\tfont-weight: normal;\n"], ["\n\tfont-weight: normal;\n"])));
var ModalButton = function (props) {
    return 'href' in props && props.href ? (React.createElement(Button, tslib_1.__assign({ as: "a" }, props))) : (React.createElement(Button, tslib_1.__assign({}, props)));
};
var Modal = (function (_super) {
    tslib_1.__extends(Modal, _super);
    function Modal(props) {
        var _this = _super.call(this, props) || this;
        _this.ownIndex = 0;
        _this.handleKeyDown = function (e) {
            if (Modal.mountedCount !== _this.ownIndex) {
                return;
            }
            if (!e.defaultPrevented && (e.which === 13 || e.which === 27)) {
                e.preventDefault();
                e.stopPropagation();
                if (e.which === 13) {
                    _this.props.done();
                }
                if (e.which === 27) {
                    (_this.props.cancel || _this.props.done)();
                }
            }
        };
        return _this;
    }
    Modal.prototype.componentDidMount = function () {
        if (!Modal.mountedCount) {
            document.body.classList.add(bodyNoOverflowClass);
        }
        window.document.addEventListener('keydown', this.handleKeyDown);
        Modal.mountedCount++;
        this.ownIndex = Modal.mountedCount;
    };
    Modal.prototype.componentWillUnmount = function () {
        Modal.mountedCount--;
        if (!Modal.mountedCount) {
            document.body.classList.remove(bodyNoOverflowClass);
        }
        window.document.removeEventListener('keydown', this.handleKeyDown);
    };
    Modal.prototype.render = function () {
        var _a = this.props, width = _a.width, theme = _a.theme, props = tslib_1.__rest(_a, ["width", "theme"]);
        var cancelButtonProps = assign({ style: { marginRight: 20 } }, props.cancelButtonProps);
        var secondaryButtonProps = assign({
            primary: true,
            outline: true,
            style: { marginRight: 20 },
        }, props.secondaryButtonProps);
        var primaryButtonProps = assign({ primary: true }, props.primaryButtonProps);
        return (React.createElement(Layer, { onEsc: function () { return (props.cancel || props.done)(); }, onClickOutside: function () { return (props.cancel || props.done)(); }, responsive: false, margin: "small", animate: false },
            React.createElement(GlobalStyle, null),
            React.createElement(ModalSizer, { p: [px(theme.space[3]), '40px 50px 30px'], width: width || DEFAULT_MODAL_WIDTH, onClick: stopPropagation, style: props.style, id: props.id, className: props.className },
                props.titleElement ? (React.createElement(Heading.h3, { mb: 50 }, props.titleElement)) : (!!props.title && (React.createElement(Heading.h3, { mb: 50 },
                    props.title,
                    !!props.titleDetails && (React.createElement(HeadingDescription, { color: "text.light", fontSize: 2 }, props.titleDetails))))),
                props.children,
                React.createElement(Flex, { mt: 50, alignItems: "center", justifyContent: "flex-end" },
                    props.cancel && (React.createElement(ModalButton, tslib_1.__assign({}, cancelButtonProps, { onClick: props.cancel }), (cancelButtonProps && cancelButtonProps.children) || 'Cancel')),
                    props.secondaryButtonProps && (React.createElement(ModalButton, tslib_1.__assign({}, secondaryButtonProps))),
                    React.createElement(ModalButton, tslib_1.__assign({}, primaryButtonProps, { onClick: props.done }), props.action || 'OK')))));
    };
    Modal.mountedCount = 0;
    return Modal;
}(React.Component));
export default withTheme(Modal);
var templateObject_1, templateObject_2, templateObject_3;
